Method: Nyaplot::CircularPlot#fill_by

Defined in:
lib/bionya/plot.rb

#fill_bySymbol

Returns the name of column that decides what colors to be filled in.

Returns:

  • (Symbol)

    the name of column that decides what colors to be filled in



22
# File 'lib/bionya/plot.rb', line 22

define_group_properties(:axis_extra_options, [:df_id, :inner_radius, :outer_radius, :group_by, :axis, :chord, :matrix, :inner_num, :outer_num, :color, :text_color, :text_size, :fill_by, :padding])