Method: Nyaplot::Diagrams::Labels#layer

Defined in:
lib/bionya/diagram.rb

#layerNumeric

Returns The number of layer where the plot is placed.

Returns:

  • (Numeric)

    The number of layer where the plot is placed



49
# File 'lib/bionya/diagram.rb', line 49

define_group_properties(:options, [:color, :fill_by, :x, :text, :stroke_width, :layer, :text_size])