Method: Nyaplot::Diagrams::Scatter#fill_by

Defined in:
lib/nyaplot/diagram.rb

#fill_bySymbol

Returns the column label to decide how to fill sybmols.

Returns:

  • (Symbol)

    the column label to decide how to fill sybmols



165
# File 'lib/nyaplot/diagram.rb', line 165

define_group_properties(:options, [:title, :x, :y, :fill_by, :shape_by, :size_by, :color, :shape, :size, :stroke_color, :stroke_width, :tooltip_contents])